@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0507';
+our $VERSION = '0.0508';
 
 use Moo;
 use strictures 2;
@@ -122,11 +122,10 @@ sub generate {
     $chord ||= 'C';
     $num   ||= 4;
 
-    my ($chord_note, $flavor) = _parse_chord($chord);
-    if ($flavor =~ /^\//) {
-        $flavor = '';
-        $chord  = $chord_note;
+    if ($chord =~ /^(.+)\//) {
+        $chord  = $1;
     }
+    my ($chord_note, $flavor) = _parse_chord($chord);
 
     my $next_chord_note;
     ($next_chord_note) = _parse_chord($next_chord)
@@ -300,7 +299,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0507
+version 0.0508
 
 =head1 SYNOPSIS
 
